Learn R Programming

symMCD (version 0.6)

symMCD-package: tools:::Rd_package_title("symMCD")

Description

tools:::Rd_package_description("symMCD")

Arguments

Author

tools:::Rd_package_author("symMCD")

Maintainer: tools:::Rd_package_maintainer("symMCD")

Details

tools:::Rd_package_DESCRIPTION("symMCD")

The minimum covariance determinant (MCD) estimator is one of the most popular robust scatter matrix estimators; however, it does not possess the independence property. The symmetrized MCD is a variant of the MCD that does satisfy this property. It is, however, computationally more demanding, as it is based on all pairwise differences of the observations. On the other hand, the symmetrized MCD does not require a location estimate, since it is inherently centered at the origin.

To reduce the computational burden, an approximate variant of the symmetrized MCD is also implemented. This variant does not use all pairwise differences, but instead relies on a subset of size \(n m\), where \(n\) denotes the sample size and \(m\) is a user-specified integer.

In addition, several helper functions are provided to support the computation and use of the symmetrized MCD.

tools:::Rd_package_indices("symMCD")

References

Croux, C. and Nordhausen, K. (2026). Symmetrized MCD. Unpublished manuscript.